@@ -1,3 +1,4 @@
+"""Contains abstract class for data loading and saving."""
 import locale
 import sys
 from collections import OrderedDict
@@ -13,18 +14,18 @@ logger = dp_logging.get_child_logger(__name__)
 
 
 class BaseData(object):
-    """
-    Abstract class for data loading and saving
-    """
+    """Abstract class for data loading and saving."""
 
     data_type = None
     info = None
 
     def __init__(self, input_file_path, data, options):
         """
-        Base class for loading a dataset. Options can be specified and maybe
+        Initialize Base class for loading a dataset.
+
+        Options can be specified and maybe
         more specific to the subclasses.
-        
+
         :param input_file_path: path to the file being loaded or None
         :type input_file_path: str
         :param data: data being loaded into the class instead of an input file
@@ -57,10 +58,11 @@ class BaseData(object):
         self._data = data
         self._batch_info = dict(perm=list(), iter=0)
         self._tmp_file_name = None
-        self._file_encoding = options.get('encoding', None)
+        self._file_encoding = options.get("encoding", None)
 
     @property
     def data(self):
+        """Return data."""
         if self._data is None:
             self._load_data()
 
@@ -78,13 +80,12 @@ class BaseData(object):
 
     @property
     def data_format(self):
+        """Return data format."""
         return self._selected_data_format
 
     @property
     def is_structured(self):
-        """
-        Determines compatibility with StructuredProfiler
-        """
+        """Determine compatibility with StructuredProfiler."""
         raise NotImplementedError
 
     @data_format.setter
@@ -100,39 +101,41 @@ class BaseData(object):
 
     @property
     def file_encoding(self):
+        """Return file encoding."""
         if not self._file_encoding:
             # get system default, but if set to ascii, just update to utf-8
             file_encoding = "utf-8"
             try:
                 file_encoding = locale.getpreferredencoding(False)
-            except:
+            except Exception:
                 file_encoding = sys.getfilesystemencoding()
             finally:
-                if file_encoding.lower() in ['ansi_x3.4-1968', 'ascii']:
-                    file_encoding = 'utf-8'
+                if file_encoding.lower() in ["ansi_x3.4-1968", "ascii"]:
+                    file_encoding = "utf-8"
             self._file_encoding = file_encoding
 
             # set to default, detect if not StringIO
-            if self.input_file_path \
-                    and not isinstance(self.input_file_path, StringIO):
+            if self.input_file_path and not isinstance(self.input_file_path, StringIO):
                 self._file_encoding = data_utils.detect_file_encoding(
-                    self.input_file_path)
+                    self.input_file_path
+                )
         return self._file_encoding
 
     @file_encoding.setter
     def file_encoding(self, value):
-        valid_user_set_encodings = [
-            "ascii", "utf-8", "utf-16", "utf-32"
-        ]
+        """Set file encoding."""
+        valid_user_set_encodings = ["ascii", "utf-8", "utf-16", "utf-32"]
         if not value or value.lower() not in valid_user_set_encodings:
             raise ValueError(
-                "File Encoding must be one of the following: {}"
-                .format(valid_user_set_encodings)
-             )
+                "File Encoding must be one of the following: {}".format(
+                    valid_user_set_encodings
+                )
+            )
         self._file_encoding = value
 
     @staticmethod
     def _check_and_return_options(options):
+        """Return options or raise error."""
         if not options:
             options = dict()
         elif not isinstance(options, dict):
@@ -140,26 +143,31 @@ class BaseData(object):
         return options
 
     def _load_data(self, data=None):
+        """Load data."""
         raise NotImplementedError()
 
     def get_batch_generator(self, batch_size):
+        """Get batch generator."""
         data_length = len(self.data)
         indices = np.random.permutation(data_length)
         for i in range(0, data_length, batch_size):
             if isinstance(self.data, pd.DataFrame):
-                yield self.data.iloc[indices[i:i + batch_size], :]
+                yield self.data.iloc[indices[i : i + batch_size], :]
             else:
-                yield list(self.data[k] for k in indices[i:i + batch_size])
+                yield list(self.data[k] for k in indices[i : i + batch_size])
 
     @classmethod
     def is_match(cls, input_file_path, options):
+        """Return true if match, false otherwise."""
         raise NotImplementedError()
 
     def reload(self, input_file_path, data, options):
         """
-        Reload the data class with a new dataset. This erases all existing
+        Reload the data class with a new dataset.
+
+        This erases all existing
         data/options and replaces it with the input data/options.
-        
+
         :param input_file_path: path to the file being loaded or None
         :type input_file_path: str
         :param data: data being loaded into the class instead of an input file
@@ -169,9 +177,7 @@ class BaseData(object):
         :return: None
         """
         if input_file_path and not self.is_match(input_file_path, options):
-            raise ValueError(
-                "Reloaded dataset does not match the specified data_type"
-            )
+            raise ValueError("Reloaded dataset does not match the specified data_type")
         elif input_file_path:
             self.input_file_path = input_file_path
         self._data = None
@@ -181,7 +187,7 @@ class BaseData(object):
 
     def __len__(self):
         """
-        Returns the length of the dataset which is loaded.
+        Return the length of the dataset which is loaded.
 
         :return: length of the dataset
         """
@@ -190,7 +196,7 @@ class BaseData(object):
     @property
     def length(self):
         """
-        Returns the length of the dataset which is loaded.
+        Return the length of the dataset which is loaded.
 
         :return: length of the dataset
         """
@@ -198,7 +204,9 @@ class BaseData(object):
 
     def __getattribute__(self, name):
         """
-        Overrides getattr for the class such that functions can be applied
+        Override getattr for the class.
+
+        Do this such that functions can be applied
         directly to the data class if the function is not part of the data
         class.
         e.g. if data is BaseData where self.data = [1, 2, 3, 1]
@@ -211,16 +219,20 @@ class BaseData(object):
         except AttributeError as attr_error:
             class_name = self.__class__.__name__
             data_class_name = self.data.__class__.__name__
-            if (not f"'{class_name}' object has no attribute '{name}'"
-                    == str(attr_error)):
+            if not f"'{class_name}' object has no attribute '{name}'" == str(
+                attr_error
+            ):
                 raise
             try:
                 returned = object.__getattribute__(self.data, name)
             except AttributeError as attr_error:
-                if (not f"'{data_class_name}' object has no attribute '{name}'"
-                        == str(attr_error)):
+                if not f"'{data_class_name}' object has no attribute '{name}'" == str(
+                    attr_error
+                ):
                     raise
-                raise AttributeError(f"Neither '{class_name}' nor "
-                                     f"'{data_class_name}' objects have "
-                                     f"attribute '{name}'")
+                raise AttributeError(
+                    f"Neither '{class_name}' nor "
+                    f"'{data_class_name}' objects have "
+                    f"attribute '{name}'"
+                )
         return returned
