@@ -1,3 +1,4 @@
+"""Contains class for profiling datetime column."""
 import datetime
 import re
 import warnings
@@ -6,15 +7,15 @@ import numpy as np
 import pandas as pd
 
 from . import utils
-from .base_column_profilers import BaseColumnPrimitiveTypeProfiler, \
-    BaseColumnProfiler
+from .base_column_profilers import BaseColumnPrimitiveTypeProfiler, BaseColumnProfiler
 from .profiler_options import DateTimeOptions
 
 
 class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
     """
-    Datetime column profile subclass of BaseColumnProfiler. Represents a column
-    int the dataset which is a datetime column.
+    Datetime column profile subclass of BaseColumnProfiler.
+
+    Represents a column int the dataset which is a datetime column.
     """
 
     type = "datetime"
@@ -35,7 +36,7 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         "%d%b%y",  # 12Mar13
         "%b-%d-%y",  # Mar-13-13
         "%m%d%Y",  # 03142013
-        "%H:%M:%S.%f"  # 05:46:30.258509
+        "%H:%M:%S.%f",  # 05:46:30.258509
     ]
 
     _day_suffixes = [
@@ -45,20 +46,23 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         "th",
     ]
 
-    _compiled_day_suffix_regex = re.compile("(\d{1,2})(" + '|'.join(_day_suffixes) + ")")
+    _compiled_day_suffix_regex = re.compile(
+        r"(\d{1,2})(" + "|".join(_day_suffixes) + ")"
+    )
 
     def __init__(self, name, options=None):
         """
-        Initialization of column base properties and itself.
-        
+        Initialize it and the column base properties.
+
         :param name: Name of the data
         :type name: String
         :param options: Options for the datetime column
         :type options: DateTimeOptions
         """
         if options and not isinstance(options, DateTimeOptions):
-            raise ValueError("DateTimeColumn parameter 'options' must be of "
-                             "type DateTimeOptions.")
+            raise ValueError(
+                "DateTimeColumn parameter 'options' must be of " "type DateTimeOptions."
+            )
         BaseColumnPrimitiveTypeProfiler.__init__(self, name)
         self.date_formats = []
         self.min = None
@@ -71,21 +75,22 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
 
     def __add__(self, other):
         """
-        Merges the properties of two DateTimeColumn profiles
+        Merge the properties of two DateTimeColumn profiles.
 
         :param other: second profile
         :type other: DateTimeColumn
         """
         if not isinstance(other, DateTimeColumn):
-            raise TypeError("Unsupported operand type(s) for +: "
-                            "'DateTimeColumn' and '{}'".format(
-                                other.__class__.__name__))
+            raise TypeError(
+                "Unsupported operand type(s) for +: "
+                "'DateTimeColumn' and '{}'".format(other.__class__.__name__)
+            )
 
         merged_profile = DateTimeColumn(name=None)
         BaseColumnPrimitiveTypeProfiler._add_helper(merged_profile, self, other)
-        self._merge_calculations(merged_profile.__calculations,
-                                 self.__calculations,
-                                 other.__calculations)
+        self._merge_calculations(
+            merged_profile.__calculations, self.__calculations, other.__calculations
+        )
 
         if self._dt_obj_min is None:
             merged_profile.min = other.min
@@ -108,12 +113,15 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
             merged_profile._dt_obj_max = other._dt_obj_max
 
         merged_profile.date_formats = utils._combine_unique_sets(
-            self.date_formats, other.date_formats)
+            self.date_formats, other.date_formats
+        )
         return merged_profile
 
     def report(self, remove_disabled_flag=False):
         """
-        Private abstract method for returning report.
+        Return report.
+
+        Private abstract method.
 
         :param remove_disabled_flag: flag to determine if disabled
             options should be excluded in the report.
@@ -123,23 +131,21 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
 
     @property
     def profile(self):
-        """
-        Property for profile. Returns the profile of the column.
-        """
+        """Return the profile of the column."""
         profile = dict(
             min=self.min,
             max=self.max,
             histogram=None,
             format=self.date_formats,
-            times=self.times
+            times=self.times,
         )
         return profile
 
     @property
     def data_type_ratio(self):
         """
-        Calculates the ratio of samples which match this data type.
-        
+        Calculate the ratio of samples which match this data type.
+
         :return: ratio of data type
         :rtype: float
         """
@@ -149,7 +155,7 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
 
     def diff(self, other_profile, options=None):
         """
-        Generates the differences between max, min, and formats of two DateTime columns
+        Generate differences between max, min, and formats of two DateTime cols.
 
         :return: Dict containing the differences between max, min, and format in their
         appropriate output formats
@@ -158,18 +164,23 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         super().diff(other_profile, options)
 
         differences = {
-            "min": utils.find_diff_of_dates(self._dt_obj_min, other_profile._dt_obj_min),
-            "max": utils.find_diff_of_dates(self._dt_obj_max, other_profile._dt_obj_max),
+            "min": utils.find_diff_of_dates(
+                self._dt_obj_min, other_profile._dt_obj_min
+            ),
+            "max": utils.find_diff_of_dates(
+                self._dt_obj_max, other_profile._dt_obj_max
+            ),
             "format": utils.find_diff_of_lists_and_sets(
-                self.date_formats, other_profile.date_formats)
+                self.date_formats, other_profile.date_formats
+            ),
         }
         return differences
 
     @staticmethod
     def _validate_datetime(date, date_format):
         """
-        Check to see if a string contains a certain date format
-        
+        Check to see if a string contains a certain date format.
+
         :param date: a string that is possibly a date
         :type date: str
         :param date_format: a date regex that will be checked against date
@@ -186,16 +197,16 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
     @staticmethod
     def _replace_day_suffix(date, pattern):
         """
-        Checks the date for a suffix after the day. Removed suffix if present
+        Check the date for a suffix after the day. Remove suffix if present.
 
         :param date: a string that is possibly a date
         :type date: str
-        :param pattern: a precompiled regex pattern that is used to check for day suffixes
+        :param pattern: precompiled regex pattern that is used to check for day suffixes
         :type pattern: Pattern
         :return: either the date string passed in, or Nan
         """
         try:
-            date = pattern.sub(r'\1', date)
+            date = pattern.sub(r"\1", date)
         except (TypeError):
             date = np.nan
         return date
@@ -203,15 +214,15 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
     @classmethod
     def _get_datetime_profile(cls, df_series):
         """
-        For each value in a column determines if it is a datetime and the format
-        of the value. Also collects datetime stats for the column.
-        
+        Determine for each val in a col its format and if it's a datetime.
+
+        Also collect datetime stats for the column.
+
         :param df_series: a given column
         :type df_series: pandas.core.series.Series
         :return: parameters for datetime columns
         :rtype: dict
         """
-
         profile = dict()
         activated_date_formats = list()
         len_df = len(df_series)
@@ -227,14 +238,15 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
                 break
             valid_dates = df_series.apply(
                 lambda x: cls._validate_datetime(
-                    cls._replace_day_suffix(x, cls._compiled_day_suffix_regex), date_format
+                    cls._replace_day_suffix(x, cls._compiled_day_suffix_regex),
+                    date_format,
                 )
             )
 
             df_dates = valid_dates[~valid_dates.isnull()]
 
             if "%b" in date_format and not df_dates.empty:
-                may_month = 5 # May can be %b or %B we want to force, so check
+                may_month = 5  # May can be %b or %B we want to force, so check
                 all_may = df_dates.apply(lambda x: x.month == may_month).all()
                 if all_may:
                     valid_dates[:] = np.nan
@@ -243,30 +255,30 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
             # Create mask to avoid null dates
             null_date_mask = valid_dates.isnull()
             np_date_array = df_dates.values
-                    
+
             # check off any values which were found to be datetime
             is_row_datetime[~is_row_datetime] = (~null_date_mask).values
 
             if len(df_dates) > 0:
-                
+
                 # Converts to numpy prior to finding max index
                 min_idx = np.argmin(np_date_array)
                 max_idx = np.argmax(np_date_array)
-                
+
                 # Selects the min, ma value objects for comparison
                 tmp_min_value_obj = df_dates.iloc[min_idx]
                 tmp_max_value_obj = df_dates.iloc[max_idx]
-                
+
                 # If minimum value, keep reference
                 if tmp_min_value_obj < min_value_obj:
                     min_value = df_series[~null_date_mask].iloc[min_idx]
                     min_value_obj = tmp_min_value_obj
-                
+
                 # If maximum value, keep reference
                 if tmp_max_value_obj > max_value_obj:
                     max_value = df_series[~null_date_mask].iloc[max_idx]
                     max_value_obj = tmp_max_value_obj
-                    
+
             df_series = df_series[null_date_mask]
 
             # Get a list of all datetime format identified in column
@@ -281,23 +293,29 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
                         "are for the 1990s. "
                         "https://stackoverflow.com/questions/37766353/"
                         "pandas-to-datetime-parsing-wrong-year",
-                        RuntimeWarning
+                        RuntimeWarning,
                     )
 
         profile["date_formats"] = activated_date_formats
         profile["min"] = min_value
         profile["max"] = max_value
-        profile["min_obj"] = min_value_obj.to_datetime() \
-            if hasattr(min_value_obj, 'to_datetime') else min_value_obj
-        profile["max_obj"] = max_value_obj.to_datetime() \
-            if hasattr(max_value_obj, 'to_datetime') else max_value_obj
+        profile["min_obj"] = (
+            min_value_obj.to_datetime()
+            if hasattr(min_value_obj, "to_datetime")
+            else min_value_obj
+        )
+        profile["max_obj"] = (
+            max_value_obj.to_datetime()
+            if hasattr(max_value_obj, "to_datetime")
+            else max_value_obj
+        )
         profile["match_count"] = is_row_datetime.sum()
         return profile
 
     def _is_subset_datetime_column(self, df_series):
         """
-        Checks whether a subset of the data could be considered datetime.
-        
+        Check whether a subset of the data could be considered datetime.
+
         :param df_series: df series
         :type df_series: pandas.core.series.Series
         :return: True or False
@@ -315,10 +333,9 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
         return True
 
     @BaseColumnProfiler._timeit(name="datetime")
-    def _update_datetime(self, df_series, prev_dependent_properties,
-                         subset_properties):
+    def _update_datetime(self, df_series, prev_dependent_properties, subset_properties):
         """
-        Calculates the datetime properties for the profile.
+        Calculate the datetime properties for the profile.
 
         :param df_series: data to check for datetime values and their properties
         :type df_series: pandas.Dataframe
@@ -361,7 +378,7 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
 
     def _update_helper(self, df_series, profile):
         """
-        Method for updating the column profile properties.
+        Update the column profile properties.
 
         :param df_series: df series with nulls removed
         :type df_series: pandas.core.series.Series
@@ -373,15 +390,15 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
 
     def update(self, df_series):
         """
-        Updates the column profile.
-        
+        Update the column profile.
+
         :param df_series: df series
         :type df_series: pandas.core.series.Series
         :return: None
         """
         if len(df_series) == 0:
             return self
-        
+
         df_series = df_series.reset_index(drop=True)
         profile = {"sample_size": len(df_series), "match_count": 0}
         if self._is_subset_datetime_column(df_series):
@@ -390,7 +407,8 @@ class DateTimeColumn(BaseColumnPrimitiveTypeProfiler):
                 self.__calculations,
                 df_series=df_series,
                 prev_dependent_properties={},
-                subset_properties=profile)
+                subset_properties=profile,
+            )
         self._update_helper(df_series=df_series, profile=profile)
 
         return self
