@@ -1,3 +1,4 @@
+"""Contains functions for profilers."""
 import collections
 import copy
 import datetime
@@ -7,6 +8,7 @@ import multiprocessing as mp
 import os
 import time
 import warnings
+from itertools import islice
 
 import numpy as np
 import psutil
@@ -31,18 +33,24 @@ def dict_merge(dct, merge_dct):
     #
     # You should have received a copy of the GNU General Public License
     # along with this program.  If not, see <https://www.gnu.org/licenses/>.
-    """ Recursive dict merge. Inspired by :meth:``dict.update()``, instead of
-    updating only top-level keys, dict_merge recurses down into dicts nested
-    to an arbitrary depth, updating keys. The ``merge_dct`` is merged into
-    ``dct``.
+    """
+    Merge dict recursively.
+
+    Inspired by :meth:``dict.update()``, instead of updating only
+    top-level keys, dict_merge recurses down into dicts nested
+    to an arbitrary depth, updating keys. The ``merge_dct`` is
+    merged into ``dct``.
 
     :param dct: dict onto which the merge is executed
     :param merge_dct: dct merged into dct
     :return: None
     """
     for k, v in merge_dct.items():
-        if (k in dct and isinstance(dct[k], dict)
-                and isinstance(merge_dct[k], collections.abc.Mapping)):
+        if (
+            k in dct
+            and isinstance(dct[k], dict)
+            and isinstance(merge_dct[k], collections.abc.Mapping)
+        ):
             dict_merge(dct[k], merge_dct[k])
         else:
             dct[k] = merge_dct[k]
@@ -50,18 +58,22 @@ def dict_merge(dct, merge_dct):
 
 class KeyDict(collections.defaultdict):
     """
-    Helper class for sample_in_chunks. Allows keys that are missing to become
-    the values for that key.
+    Helper class for sample_in_chunks.
+
+    Allows keys that are missing to become the values for that key.
     From:
     https://www.drmaciver.com/2018/01/lazy-fisher-yates-shuffling-for-precise-rejection-sampling/
     """
+
     def __missing__(self, key):
+        """Return key if key nonexistent."""
         return key
 
 
 def _combine_unique_sets(a, b):
     """
-    Method to union two lists.
+    Unify two lists.
+
     :type a: list
     :type b: list
     :rtype: list
@@ -80,8 +92,10 @@ def _combine_unique_sets(a, b):
 
 def shuffle_in_chunks(data_length, chunk_size):
     """
-    A generator for creating shuffled indexes in chunks. This reduces the cost
-    of having to create all indexes, but only of that what is needed.
+    Create shuffled indexes in chunks.
+
+    This reduces the cost of having to create all indexes,
+    but only of that what is needed.
     Initial Code idea from:
     https://www.drmaciver.com/2018/01/lazy-fisher-yates-shuffling-for-precise-rejection-sampling/
 
@@ -89,18 +103,16 @@ def shuffle_in_chunks(data_length, chunk_size):
     :param chunk_size: size of shuffled chunks
     :return: list of shuffled indices of chunk size
     """
-
-    if not data_length or data_length == 0 \
-       or not chunk_size or chunk_size == 0:
+    if not data_length or data_length == 0 or not chunk_size or chunk_size == 0:
         return []
 
     rng = np.random.default_rng(settings._seed)
 
-    if 'DATAPROFILER_SEED' in os.environ and settings._seed is None:
+    if "DATAPROFILER_SEED" in os.environ and settings._seed is None:
         try:
-            seed_value = int(os.environ.get('DATAPROFILER_SEED'))
+            seed_value = int(os.environ.get("DATAPROFILER_SEED"))
             rng = np.random.default_rng(seed_value)
-        except ValueError as e:
+        except ValueError:
             warnings.warn("Seed should be an integer", RuntimeWarning)
 
     indices = KeyDict()
@@ -135,7 +147,7 @@ def shuffle_in_chunks(data_length, chunk_size):
 
 def warn_on_profile(col_profile, e):
     """
-    Returns a warning if a given profile errors (tensorflow typically)
+    Return a warning if a given profile errors (tensorflow typically).
 
     :param col_profile: Name of the column profile
     :type col_profile: str
@@ -143,12 +155,14 @@ def warn_on_profile(col_profile, e):
     :type e: Exception
     """
     import warnings
+
     warning_msg = "\n\n!!! WARNING Partial Profiler Failure !!!\n\n"
     warning_msg += "Profiling Type: {}".format(col_profile)
     warning_msg += "\nException: {}".format(type(e).__name__)
     warning_msg += "\nMessage: {}".format(e)
     # This is considered a major error
-    if type(e).__name__ == "ValueError": raise ValueError(e)
+    if type(e).__name__ == "ValueError":
+        raise ValueError(e)
     warning_msg += "\n\nFor labeler errors, try installing "
     warning_msg += "the extra ml requirements via:\n\n"
     warning_msg += "$ pip install dataprofiler[ml] --user\n\n"
@@ -157,8 +171,7 @@ def warn_on_profile(col_profile, e):
 
 def partition(data, chunk_size):
     """
-    Creates a generator which returns the data
-    in the specified chunk size.
+    Create a generator which returns data in specified chunk size.
 
     :param data: list, dataframe, etc
     :type data: list, dataframe, etc
@@ -166,12 +179,12 @@ def partition(data, chunk_size):
     :type chunk_size: int
     """
     for idx in range(0, len(data), chunk_size):
-        yield data[idx:idx+chunk_size]
+        yield data[idx : idx + chunk_size]
 
 
 def suggest_pool_size(data_size=None, cols=None):
     """
-    Suggest the pool size based on resources
+    Suggest the pool size based on resources.
 
     :param data_size: size of the dataset
     :type data_size: int
@@ -180,7 +193,6 @@ def suggest_pool_size(data_size=None, cols=None):
     :return suggested_pool_size: suggeseted pool size
     :rtype suggested_pool_size: int
     """
-
     # Return if there's no data_size
     if data_size is None:
         return None
@@ -209,7 +221,7 @@ def suggest_pool_size(data_size=None, cols=None):
 
 def generate_pool(max_pool_size=None, data_size=None, cols=None):
     """
-    Generate a multiprocessing pool to allocate functions too
+    Generate a multiprocessing pool to allocate functions too.
 
     :param max_pool_size: Max number of processes assigned to the pool
     :type max_pool_size: Union[int, None]
@@ -222,7 +234,6 @@ def generate_pool(max_pool_size=None, data_size=None, cols=None):
     :return cpu_count: Number of processes (cpu bound) to utilize
     :rtype cpu_count: int
     """
-
     suggested_pool_size = suggest_pool_size(data_size, cols)
     if max_pool_size is None or suggested_pool_size is None:
         max_pool_size = suggested_pool_size
@@ -232,32 +243,27 @@ def generate_pool(max_pool_size=None, data_size=None, cols=None):
     if max_pool_size is not None and max_pool_size > 2:
         try:
             pool = mp.Pool(max_pool_size)
-        except Exception as e:
+        except Exception:
             pool = None
             warnings.warn(
-                'Multiprocessing disabled, please change the multiprocessing'+
-                ' start method, via: multiprocessing.set_start_method(<method>)'+
-                ' Possible methods include: fork, spawn, forkserver, None'
+                "Multiprocessing disabled, please change the multiprocessing"
+                + " start method, via: multiprocessing.set_start_method(<method>)"
+                + " Possible methods include: fork, spawn, forkserver, None"
             )
 
     return pool, max_pool_size
 
 
 def overlap(x1, x2, y1, y2):
-    """
-    Return True iff [x1:x2] overlaps with [y1:y2]
-    """
+    """Return True iff [x1:x2] overlaps with [y1:y2]."""
     if not all([isinstance(i, int) for i in [x1, x2, y1, y2]]):
         return False
-    return ((y1 <= x1 <= y2) or
-            (y1 <= x2 <= y2) or
-            (x1 <= y1 <= x2) or
-            (x1 <= y2 <= x2))
+    return (y1 <= x1 <= y2) or (y1 <= x2 <= y2) or (x1 <= y1 <= x2) or (x1 <= y2 <= x2)
 
 
 def add_nested_dictionaries(first_dict, second_dict):
     """
-    Merges two dictionaries together and adds values together
+    Merge two dictionaries together and add values together.
 
     :param first_dict: dictionary to be merged
     :type first_dict: dict
@@ -273,7 +279,8 @@ def add_nested_dictionaries(first_dict, second_dict):
         if item in second_dict:
             if isinstance(first_dict[item], dict):
                 merged_dict[item] = add_nested_dictionaries(
-                    first_dict[item], second_dict[item])
+                    first_dict[item], second_dict[item]
+                )
             else:
                 merged_dict[item] = first_dict[item] + second_dict[item]
         else:
@@ -288,7 +295,8 @@ def add_nested_dictionaries(first_dict, second_dict):
 
 def biased_skew(df_series):
     """
-    Calculates the biased estimator for skewness of the given data.
+    Calculate the biased estimator for skewness of the given data.
+
     The definition is formalized as g_1 here:
         https://en.wikipedia.org/wiki/Skewness#Sample_skewness
     :param df_series: data to get skewness of, assuming floats
@@ -305,7 +313,7 @@ def biased_skew(df_series):
         return np.nan
 
     diffs = df_series - mean
-    squared_diffs = diffs ** 2
+    squared_diffs = diffs**2
     cubed_diffs = squared_diffs * diffs
     M2 = sum(squared_diffs)
     M3 = sum(cubed_diffs)
@@ -315,17 +323,18 @@ def biased_skew(df_series):
     M2 = 0 if np.abs(M2) < 1e-14 else M2
     M3 = 0 if np.abs(M3) < 1e-14 else M3
 
-    if (M2 == 0):
+    if M2 == 0:
         return 0.0
 
-    with np.errstate(all='ignore'):
-        skew = np.sqrt(n) * M3 / np.power(M2,  1.5)
+    with np.errstate(all="ignore"):
+        skew = np.sqrt(n) * M3 / np.power(M2, 1.5)
     return skew
 
 
 def biased_kurt(df_series):
     """
-    Calculates the biased estimator for kurtosis of the given data
+    Calculate the biased estimator for kurtosis of the given data.
+
     The definition is formalized as g_2 here:
         https://en.wikipedia.org/wiki/Kurtosis#A_natural_but_biased_estimator
     :param df_series: data to get kurtosis of, assuming floats
@@ -334,7 +343,7 @@ def biased_kurt(df_series):
     :rtype: float
     """
     n = len(df_series)
-    if (n < 1):
+    if n < 1:
         return np.nan
 
     mean = sum(df_series) / n
@@ -342,7 +351,7 @@ def biased_kurt(df_series):
         return np.nan
 
     diffs = df_series - mean
-    squared_diffs = diffs ** 2
+    squared_diffs = diffs**2
     fourth_diffs = squared_diffs * squared_diffs
     M2 = sum(squared_diffs)
     M4 = sum(fourth_diffs)
@@ -352,18 +361,20 @@ def biased_kurt(df_series):
     M2 = 0 if np.abs(M2) < 1e-14 else M2
     M4 = 0 if np.abs(M4) < 1e-14 else M4
 
-    if (M2 == 0):
+    if M2 == 0:
         return -3.0
 
-    with np.errstate(all='ignore'):
+    with np.errstate(all="ignore"):
         kurt = n * M4 / np.power(M2, 2) - 3
     return kurt
 
 
 def find_diff_of_numbers(stat1, stat2):
     """
-    Finds the difference between two stats. If there is no difference, returns
-    "unchanged". For ints/floats, returns stat1 - stat2.
+    Find the difference between two stats.
+
+    If there is no difference, return "unchanged".
+    For ints/floats, returns stat1 - stat2.
 
     :param stat1: the first statistical input
     :type stat1: Union[int, float]
@@ -383,8 +394,10 @@ def find_diff_of_numbers(stat1, stat2):
 
 def find_diff_of_strings_and_bools(stat1, stat2):
     """
-    Finds the difference between two stats. If there is no difference, returns
-    "unchanged". For strings and bools, returns list containing [stat1, stat2].
+    Find the difference between two stats.
+
+    If there is no difference, return "unchanged".
+    For strings and bools, return list containing [stat1, stat2].
 
     :param stat1: the first statistical input
     :type stat1: Union[str, bool]
@@ -394,14 +407,16 @@ def find_diff_of_strings_and_bools(stat1, stat2):
     """
     diff = "unchanged"
     if stat1 != stat2:
-       diff = [stat1, stat2]
+        diff = [stat1, stat2]
     return diff
 
 
 def find_diff_of_lists_and_sets(stat1, stat2):
     """
-    Finds the difference between two stats. If there is no difference, returns
-    "unchanged". Removes duplicates and returns [unique values of stat1,
+    Find the difference between two stats.
+
+    If there is no difference, return
+    "unchanged". Remove duplicates and returns [unique values of stat1,
     shared values, unique values of stat2].
 
     :param stat1: the first statistical input
@@ -425,8 +440,10 @@ def find_diff_of_lists_and_sets(stat1, stat2):
 
 def find_diff_of_dates(stat1, stat2):
     """
-    Finds the difference between two dates. If there is no difference, returns
-    "unchanged". For dates, returns the difference in time.
+    Find the difference between two dates.
+
+    If there is no difference, return
+    "unchanged". For dates, return the difference in time.
 
     Because only days can be stored as negative values internally
     for timedelta objects, the output for these negative values is
@@ -459,9 +476,11 @@ def find_diff_of_dates(stat1, stat2):
 
 def find_diff_of_dicts(dict1, dict2):
     """
-    Finds the difference between two dicts. For each key in each dict,
-    returns "unchanged" if there's no difference, otherwise returns
-    the difference. Assumes that if the two dictionaries share the
+    Find the difference between two dicts.
+
+    For each key in each dict,
+    return "unchanged" if there's no difference, otherwise return
+    the difference. Assume that if the two dictionaries share the
     same key, their values are the same type.
 
     :param dict1: the first dict
@@ -471,7 +490,6 @@ def find_diff_of_dicts(dict1, dict2):
     :return: Difference in the keys of each dict
     :rtype: dict
     """
-
     diff = {}
     for key, value1 in dict1.items():
         value2 = dict2.get(key, None)
@@ -498,7 +516,7 @@ def find_diff_of_dicts(dict1, dict2):
 
 def find_diff_of_matrices(matrix1, matrix2):
     """
-    Finds the difference between two matrices.
+    Find the difference between two matrices.
 
     :param matrix1: the first matrix
     :type matrix1: list(list(float))
@@ -507,7 +525,6 @@ def find_diff_of_matrices(matrix1, matrix2):
     :return: Difference in the matrix
     :rtype: list(list(float))
     """
-
     diff = None
 
     if matrix1 is not None and matrix2 is not None:
@@ -521,11 +538,14 @@ def find_diff_of_matrices(matrix1, matrix2):
 
     return diff
 
+
 def find_diff_of_dicts_with_diff_keys(dict1, dict2):
     """
-    Finds the difference between two dicts. For each key in each dict,
-    returns "unchanged" if there's no difference, otherwise returns
-    the difference. Assumes that if the two dictionaries share the
+    Find the difference between two dicts.
+
+    For each key in each dict,
+    return "unchanged" if there's no difference, otherwise return
+    the difference. Assume that if the two dictionaries share the
     same key, their values are the same type.
 
     :param dict1: the first dict
@@ -535,7 +555,6 @@ def find_diff_of_dicts_with_diff_keys(dict1, dict2):
     :return: Difference in the keys of each dict
     :rtype: list
     """
-
     diff_1 = {}
     diff_shared = {}
     diff_2 = {}
@@ -567,9 +586,9 @@ def find_diff_of_dicts_with_diff_keys(dict1, dict2):
     return diff
 
 
-def get_memory_size(data, unit='M'):
+def get_memory_size(data, unit="M"):
     """
-    Get memory size of the input data
+    Get memory size of the input data.
 
     :param data: list or array of data
     :type data: Union[list, numpy.array, pandas.DataFrame]
@@ -579,19 +598,22 @@ def get_memory_size(data, unit='M'):
     """
     unit_map = collections.defaultdict(B=0, K=1, M=2, G=3)
     if unit not in unit_map:
-        raise ValueError('Currently only supports the '
-                         'memory size unit in {}'.format(list(unit_map.keys())))
+        raise ValueError(
+            "Currently only supports the "
+            "memory size unit in {}".format(list(unit_map.keys()))
+        )
     memory_size = 0
     for sentence in data:
-        memory_size += len(sentence.encode('utf-8'))
+        memory_size += len(sentence.encode("utf-8"))
     memory_size /= 1024.0 ** unit_map[unit]  # Conversion based on unit_map
     return memory_size
 
 
 def method_timeit(method=None, name=None):
     """
-    Measure execution time of provided method
-    Records time into times dictionary
+    Measure execution time of provided method.
+
+    Record time into times dictionary.
 
     :param method: method to time
     :type method: Callable
@@ -609,7 +631,7 @@ def method_timeit(method=None, name=None):
             ts = time.time()
             result = method(self, *args, **kw)
             te = time.time()
-            self.times[name_dec] += (te - ts)
+            self.times[name_dec] += te - ts
             return result
 
         return wrapper
@@ -618,10 +640,12 @@ def method_timeit(method=None, name=None):
         return decorator(method, name_dec=name)
     return decorator
 
-def perform_chi_squared_test_for_homogeneity(categories1, sample_size1,
-                                             categories2, sample_size2):
+
+def perform_chi_squared_test_for_homogeneity(
+    categories1, sample_size1, categories2, sample_size2
+):
     """
-    Performs a Chi Squared test for homogeneity between two groups.
+    Perform a Chi Squared test for homogeneity between two groups.
 
     :param categories1: Categories and respective counts of the first group
     :type categories1: dict
@@ -634,20 +658,19 @@ def perform_chi_squared_test_for_homogeneity(categories1, sample_size1,
     :return: Results of the chi squared test
     :rtype: dict
     """
-    results = {
-        "chi2-statistic": None,
-        "df": None,
-        "p-value": None
-    }
+    results = {"chi2-statistic": None, "df": None, "p-value": None}
 
     cat_counts = add_nested_dictionaries(categories1, categories2)
 
-    # If one or less categories, we have zero/negative degrees of freedom, which is not an
-    # appropriate value for this context
+    # If one or less categories, we have zero/negative degrees of freedom,
+    # which is not an appropriate value for this context
     num_cats = len(cat_counts)
     if len(cat_counts) <= 1:
-        warnings.warn("Insufficient number of categories. "
-                      "Chi-squared test cannot be performed.", RuntimeWarning)
+        warnings.warn(
+            "Insufficient number of categories. "
+            "Chi-squared test cannot be performed.",
+            RuntimeWarning,
+        )
         return results
 
     # Calculate degrees of freedom
@@ -670,10 +693,8 @@ def perform_chi_squared_test_for_homogeneity(categories1, sample_size1,
     for cat, count in cat_counts.items():
         expected1 = sample_size1 * count / total
         expected2 = sample_size2 * count / total
-        chi2_statistic += (categories1.get(cat, 0) - expected1) \
-                          ** 2 / expected1
-        chi2_statistic += (categories2.get(cat, 0) - expected2) \
-                          ** 2 / expected2
+        chi2_statistic += (categories1.get(cat, 0) - expected1) ** 2 / expected1
+        chi2_statistic += (categories2.get(cat, 0) - expected2) ** 2 / expected2
     results["chi2-statistic"] = chi2_statistic
 
     # Calculate p-value, i.e. P(X > chi2_statistic)
@@ -681,3 +702,60 @@ def perform_chi_squared_test_for_homogeneity(categories1, sample_size1,
     results["p-value"] = p_value
 
     return results
+
+
+def chunk(it, size):
+    """
+    Chunk things out.
+
+    :param top_profile: Categories and respective counts of the second group
+    :type top_profile: list
+    :param other_profile: Number of samples in second group
+    :type other_profile: int
+    :return: Merge of two profile objects
+    :rtype: Profile
+    """
+    it = iter(it)
+    return iter(lambda: tuple(islice(it, size)), ())
+
+
+def merge(top_profile, other_profile=None):
+    """
+    Merge two Profiles.
+
+    :param top_profile: Categories and respective counts of the second group
+    :type top_profile: list
+    :param other_profile: Number of samples in second group
+    :type other_profile: int
+    :return: Merge of two profile objects
+    :rtype: Profile
+    """
+    if not other_profile:
+        return top_profile
+    return top_profile + other_profile
+
+
+def merge_profile_list(list_of_profiles, pool_count=5):
+    """Merge list of profiles into a single profile.
+
+    :param list_of_profiles: Categories and respective counts of the second group
+    :type list_of_profiles: list
+    :param pool_count: Number of samples in second group
+    :type pool_count: int
+    :return: Single profile that is the merge of all profiles in the
+        `list_of_profiles` list.
+    :rtype: Profile
+    """
+    # remove the labeler model from the first profile object
+    # assuming that the labeler models are all the same across each profile
+    # in the list
+    for profile_idx, profile in enumerate(list_of_profiles):
+        data_labeler = list_of_profiles[profile_idx]._remove_data_labelers()
+
+    while len(list_of_profiles) > 1:
+        list_of_profiles = chunk(list_of_profiles, 2)
+        with mp.Pool(pool_count) as p:
+            list_of_profiles = p.starmap(merge, list_of_profiles)
+
+    list_of_profiles[0]._restore_data_labelers(data_labeler)
+    return list_of_profiles[0]
